@@ -1,22 +1,7 @@
-/*  This file is part of the KDevelop PHP Documentation Plugin
+/*
+    SPDX-FileCopyrightText: 2012 Milian Wolff <mail@milianw.de>
 
-    Copyright 2012 Milian Wolff <mail@milianw.de>
-
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of
-    the License or (at your option) version 3 or any later version
-    accepted by the membership of KDE e.V. (or its successor approved
-    by the membership of KDE e.V.), which shall act as a proxy
-    defined in Section 14 of version 3 of the license.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #ifndef PHPDOCSPLUGIN_H
@@ -24,6 +9,7 @@
 
 #include <interfaces/iplugin.h>
 #include <interfaces/idocumentationprovider.h>
+#include <interfaces/idocumentation.h>
 #include <QAbstractListModel>
 #include <QVariantList>
 
@@ -47,9 +33,12 @@ class PhpDocsPlugin : public KDevelop::IPlugin, public KDevelop::IDocumentationP
     QString name() const override;
     KDevelop::IDocumentation::Ptr homePage() const override;
 
+    int configPages() const override;
+    KDevelop::ConfigPage* configPage(int number, QWidget* parent) override;
+
     void showDocumentation(const QUrl& url);
 
-  public slots:
+  public Q_SLOTS:
     void loadUrl(const QUrl &url) const;
 
   private:
@@ -57,9 +46,6 @@ class PhpDocsPlugin : public KDevelop::IPlugin, public KDevelop::IDocumentationP
 
     QString getDocumentationFilename(KDevelop::Declaration* dec, const bool& isLocal) const;
     PhpDocsModel* m_model;
-
-  private slots:
-    void readConfig();
 };
 
 #endif // PHPDOCSPLUGIN_H
