@@ -1,21 +1,10 @@
-/*****************************************************************************
- * Copyright (c) 2007 Piyush verma <piyush.verma@gmail.com>                  *
- * Copyright (c) 2009 Niko Sams <niko.sams@gmail.com>                        *
- * Copyright (c) 2010 Milian Wolff <mail@milianw.de>                         *
- *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
- * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
- * (at your option) any later version.                                       *
- *                                                                           *
- * This program is distributed in the hope that it will be useful,           *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
- * GNU General Public License for more details.                              *
- *                                                                           *
- * You should have received a copy of the GNU General Public License         *
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
- *****************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Piyush verma <piyush.verma@gmail.com>
+    SPDX-FileCopyrightText: 2009 Niko Sams <niko.sams@gmail.com>
+    SPDX-FileCopyrightText: 2010 Milian Wolff <mail@milianw.de>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "phplanguagesupport.h"
 
@@ -23,7 +12,6 @@
 #include <QReadWriteLock>
 
 #include <kpluginfactory.h>
-#include <kpluginloader.h>
 #include <KTextEditor/Document>
 
 #include <interfaces/icore.h>
@@ -195,3 +183,5 @@ Range LanguageSupport::specialLanguageObjectRange(const QUrl& url, const Cursor&
 }
 
 #include "phplanguagesupport.moc"
+
+#include "moc_phplanguagesupport.cpp"
